Make the Philosopher's Stone.

@queue

- [ ] nigredo, the blackening or melanosis
- [ ] albedo, the whitening or leucosis
- [ ] citrinitas, the yellowing or xanthosis
- [ ] rubedo, the reddening, purpling, or iosis
